import { visit, concatAST, Kind } from 'graphql';
import { ApolloAngularVisitor } from './visitor';
import { extname } from 'path';
import gql from 'graphql-tag';
export const plugin = (schema, documents, config) => {
    const allAst = concatAST(documents.reduce((prev, v) => {
        return [...prev, v.content];
    }, []));
    const operations = allAst.definitions.filter(d => d.kind === Kind.OPERATION_DEFINITION);
    if (operations.length === 0) {
        return '';
    }
    const allFragments = allAst.definitions.filter(d => d.kind === Kind.FRAGMENT_DEFINITION);
    const visitor = new ApolloAngularVisitor(allFragments, operations, config);
    const visitorResult = visit(allAst, { leave: visitor });
    return [
        visitor.getImports(),
        visitor.fragments,
        ...visitorResult.definitions.filter(t => typeof t === 'string')
    ].join('\n');
};
export const addToSchema = gql `
  directive @NgModule(module: String!) on OBJECT | FIELD
  directive @namedClient(name: String!) on OBJECT | FIELD
`;
export const validate = async (schema, documents, config, outputFile) => {
    if (extname(outputFile) !== '.ts') {
        throw new Error(`Plugin "apollo-angular" requires extension to be ".ts"!`);
    }
};
//# sourceMappingURL=index.js.map